==> munit-runner-2.2.0-sources.jar: org/mule/munit/runner/processors/MunitModule.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.runner.processors;

import javax.inject.Inject;

import org.mule.munit.common.behavior.BehaviorManager;
import org.mule.munit.runner.component.rules.TestDescription;
import org.mule.munit.runner.component.rules.TestRule;
import org.mule.runtime.api.artifact.Registry;
import org.mule.runtime.api.component.AbstractComponent;

import java.util.Collection;

/**
 * <p>
 * Model representing the MUnit configuration
 * </p>
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class MunitModule extends AbstractComponent {

  @Inject
  protected Registry muleRegistry;

  /**
   * Defines if the flow sources should be disabled or not
   */
  protected boolean disableFlowSources = true;

  /**
   * List of flows to exclude from disableFlowSources configuration
   */
  protected EnableFlowSources enableFlowSources = new EnableFlowSources();

  protected Parameterizations parameterizations = new Parameterizations();

  private boolean ignore;
  private String minMuleVersion;

  public void setDisableFlowSources(boolean disableFlowSources) {
    this.disableFlowSources = disableFlowSources;
  }

  public boolean isDisableFlowSources() {
    return disableFlowSources;
  }

  @Deprecated
  public void setEnableFlowSources(EnableFlowSources enableFlowSources) {
    this.enableFlowSources = enableFlowSources;
  }

  public void addEnableFlowSources(EnableFlowSources enableFlowSources) {
    this.enableFlowSources.getFlows().addAll(enableFlowSources.getFlows());
  }

  public EnableFlowSources getEnableFlowSources() {
    return enableFlowSources;
  }

  public Parameterizations getParameterizations() {
    return parameterizations;
  }

  public void setParameterizations(Parameterizations parameterizations) {
    this.parameterizations = parameterizations;
  }

  public void applyRules(TestDescription testDescription) {
    lookupRules().forEach(testRule -> testRule.apply(testDescription));
  }

  public void reset() {
    muleRegistry.<BehaviorManager>lookupByName(BehaviorManager.ID).ifPresent(BehaviorManager::reset);
    lookupRules().forEach(TestRule::reset);
  }

  private Collection<TestRule> lookupRules() {
    return muleRegistry.lookupAllByType(TestRule.class);
  }

  public String getName() {
    return this.getLocation().getRootContainerName();
  }

  public boolean isIgnored() {
    return ignore;
  }

  public String getMinMuleVersion() {
    return minMuleVersion;
  }

  public void setIgnore(boolean ignore) {
    this.ignore = ignore;
  }

  public void setMinMuleVersion(String minMuleVersion) {
    this.minMuleVersion = minMuleVersion;
  }
}

==> munit-runner-2.2.2-sources.jar: org/mule/munit/runner/processors/MunitModule.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.runner.processors;

import javax.inject.Inject;

import org.mule.munit.common.behavior.BehaviorManager;
import org.mule.munit.runner.component.rules.TestDescription;
import org.mule.munit.runner.component.rules.TestRule;
import org.mule.runtime.api.artifact.Registry;
import org.mule.runtime.api.component.AbstractComponent;

import java.util.Collection;

/**
 * <p>
 * Model representing the MUnit configuration
 * </p>
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class MunitModule extends AbstractComponent {

  @Inject
  protected Registry muleRegistry;

  /**
   * Defines if the flow sources should be disabled or not
   */
  protected boolean disableFlowSources = true;

  /**
   * List of flows to exclude from disableFlowSources configuration
   */
  protected EnableFlowSources enableFlowSources = new EnableFlowSources();

  protected Parameterizations parameterizations = new Parameterizations();

  private boolean ignore;
  private String minMuleVersion;
  private String requiredProduct;

  public void setDisableFlowSources(boolean disableFlowSources) {
    this.disableFlowSources = disableFlowSources;
  }

  public boolean isDisableFlowSources() {
    return disableFlowSources;
  }

  @Deprecated
  public void setEnableFlowSources(EnableFlowSources enableFlowSources) {
    this.enableFlowSources = enableFlowSources;
  }

  public void addEnableFlowSources(EnableFlowSources enableFlowSources) {
    this.enableFlowSources.getFlows().addAll(enableFlowSources.getFlows());
  }

  public EnableFlowSources getEnableFlowSources() {
    return enableFlowSources;
  }

  public Parameterizations getParameterizations() {
    return parameterizations;
  }

  public void setParameterizations(Parameterizations parameterizations) {
    this.parameterizations = parameterizations;
  }

  public void applyRules(TestDescription testDescription) {
    lookupRules().forEach(testRule -> testRule.apply(testDescription));
  }

  public void reset() {
    muleRegistry.<BehaviorManager>lookupByName(BehaviorManager.ID).ifPresent(BehaviorManager::reset);
    lookupRules().forEach(TestRule::reset);
  }

  private Collection<TestRule> lookupRules() {
    return muleRegistry.lookupAllByType(TestRule.class);
  }

  public String getName() {
    return this.getLocation().getRootContainerName();
  }

  public boolean isIgnored() {
    return ignore;
  }

  public String getMinMuleVersion() {
    return minMuleVersion;
  }

  public void setIgnore(boolean ignore) {
    this.ignore = ignore;
  }

  public void setMinMuleVersion(String minMuleVersion) {
    this.minMuleVersion = minMuleVersion;
  }

  public String getRequiredProduct() {
    return requiredProduct;
  }

  public void setRequiredProduct(String requiredProduct) {
    this.requiredProduct = requiredProduct;
  }
}
